==> istio-model-v1alpha3-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/HeadersFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HeadersFluent<A extends HeadersFluent<A>> extends BaseFluent<A>{
  public HeadersFluent() {
  }
  public HeadersFluent(Headers instance) {
    instance = (instance != null ? instance : new Headers());

    if (instance != null) {
      this.withRequest(instance.getRequest());
      this.withResponse(instance.getResponse());
      this.withRequest(instance.getRequest());
      this.withResponse(instance.getResponse());
    }
  }
  private HeadersHeaderOperationsBuilder request;
  private HeadersHeaderOperationsBuilder response;
  public HeadersHeaderOperations buildRequest() {
    return this.request!=null ?this.request.build():null;
  }
  public A withRequest(HeadersHeaderOperations request) {
    _visitables.get("request").remove(this.request);
    if (request!=null){ this.request= new HeadersHeaderOperationsBuilder(request); _visitables.get("request").add(this.request);} else { this.request = null; _visitables.get("request").remove(this.request); } return (A) this;
  }
  public boolean hasRequest() {
    return this.request != null;
  }
  public RequestNested<A> withNewRequest() {
    return new RequestNested(null);
  }
  public RequestNested<A> withNewRequestLike(HeadersHeaderOperations item) {
    return new RequestNested(item);
  }
  public RequestNested<A> editRequest() {
    return withNewRequestLike(java.util.Optional.ofNullable(buildRequest()).orElse(null));
  }
  public RequestNested<A> editOrNewRequest() {
    return withNewRequestLike(java.util.Optional.ofNullable(buildRequest()).orElse(new HeadersHeaderOperationsBuilder().build()));
  }
  public RequestNested<A> editOrNewRequestLike(HeadersHeaderOperations item) {
    return withNewRequestLike(java.util.Optional.ofNullable(buildRequest()).orElse(item));
  }
  public HeadersHeaderOperations buildResponse() {
    return this.response!=null ?this.response.build():null;
  }
  public A withResponse(HeadersHeaderOperations response) {
    _visitables.get("response").remove(this.response);
    if (response!=null){ this.response= new HeadersHeaderOperationsBuilder(response); _visitables.get("response").add(this.response);} else { this.response = null; _visitables.get("response").remove(this.response); } return (A) this;
  }
  public boolean hasResponse() {
    return this.response != null;
  }
  public ResponseNested<A> withNewResponse() {
    return new ResponseNested(null);
  }
  public ResponseNested<A> withNewResponseLike(HeadersHeaderOperations item) {
    return new ResponseNested(item);
  }
  public ResponseNested<A> editResponse() {
    return withNewResponseLike(java.util.Optional.ofNullable(buildResponse()).orElse(null));
  }
  public ResponseNested<A> editOrNewResponse() {
    return withNewResponseLike(java.util.Optional.ofNullable(buildResponse()).orElse(new HeadersHeaderOperationsBuilder().build()));
  }
  public ResponseNested<A> editOrNewResponseLike(HeadersHeaderOperations item) {
    return withNewResponseLike(java.util.Optional.ofNullable(buildResponse()).orElse(item));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HeadersFluent that = (HeadersFluent) o;
    if (!java.util.Objects.equals(request, that.request)) return false;

    if (!java.util.Objects.equals(response, that.response)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(request,  response,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (request != null) { sb.append("request:"); sb.append(request + ","); }
    if (response != null) { sb.append("response:"); sb.append(response); }
    sb.append("}");
    return sb.toString();
  }
  public class RequestNested<N> extends HeadersHeaderOperationsFluent<RequestNested<N>> implements Nested<N>{
    RequestNested(HeadersHeaderOperations item) {
      this.builder = new HeadersHeaderOperationsBuilder(this, item);
    }
    HeadersHeaderOperationsBuilder builder;
    public N and() {
      return (N) HeadersFluent.this.withRequest(builder.build());
    }
    public N endRequest() {
      return and();
    }
    
  }
  public class ResponseNested<N> extends HeadersHeaderOperationsFluent<ResponseNested<N>> implements Nested<N>{
    ResponseNested(HeadersHeaderOperations item) {
      this.builder = new HeadersHeaderOperationsBuilder(this, item);
    }
    HeadersHeaderOperationsBuilder builder;
    public N and() {
      return (N) HeadersFluent.this.withResponse(builder.build());
    }
    public N endResponse() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/HeadersFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class HeadersFluent<A extends HeadersFluent<A>> extends BaseFluent<A>{
  public HeadersFluent() {
  }
  
  public HeadersFluent(Headers instance) {
    this.copyInstance(instance);
  }
  private HeadersHeaderOperationsBuilder request;
  private HeadersHeaderOperationsBuilder response;
  
  protected void copyInstance(Headers instance) {
    instance = (instance != null ? instance : new Headers());
  
    if (instance != null) {
        this.withRequest(instance.getRequest());
        this.withResponse(instance.getResponse());
        this.withRequest(instance.getRequest());
        this.withResponse(instance.getResponse());
      }
  }
  
  public HeadersHeaderOperations buildRequest() {
    return this.request!=null ?this.request.build():null;
  }
  
  public A withRequest(HeadersHeaderOperations request) {
    _visitables.get("request").remove(this.request);
    if (request!=null){ this.request= new HeadersHeaderOperationsBuilder(request); _visitables.get("request").add(this.request);} else { this.request = null; _visitables.get("request").remove(this.request); } return (A) this;
  }
  
  public boolean hasRequest() {
    return this.request != null;
  }
  
  public RequestNested<A> withNewRequest() {
    return new RequestNested(null);
  }
  
  public RequestNested<A> withNewRequestLike(HeadersHeaderOperations item) {
    return new RequestNested(item);
  }
  
  public RequestNested<A> editRequest() {
    return withNewRequestLike(java.util.Optional.ofNullable(buildRequest()).orElse(null));
  }
  
  public RequestNested<A> editOrNewRequest() {
    return withNewRequestLike(java.util.Optional.ofNullable(buildRequest()).orElse(new HeadersHeaderOperationsBuilder().build()));
  }
  
  public RequestNested<A> editOrNewRequestLike(HeadersHeaderOperations item) {
    return withNewRequestLike(java.util.Optional.ofNullable(buildRequest()).orElse(item));
  }
  
  public HeadersHeaderOperations buildResponse() {
    return this.response!=null ?this.response.build():null;
  }
  
  public A withResponse(HeadersHeaderOperations response) {
    _visitables.get("response").remove(this.response);
    if (response!=null){ this.response= new HeadersHeaderOperationsBuilder(response); _visitables.get("response").add(this.response);} else { this.response = null; _visitables.get("response").remove(this.response); } return (A) this;
  }
  
  public boolean hasResponse() {
    return this.response != null;
  }
  
  public ResponseNested<A> withNewResponse() {
    return new ResponseNested(null);
  }
  
  public ResponseNested<A> withNewResponseLike(HeadersHeaderOperations item) {
    return new ResponseNested(item);
  }
  
  public ResponseNested<A> editResponse() {
    return withNewResponseLike(java.util.Optional.ofNullable(buildResponse()).orElse(null));
  }
  
  public ResponseNested<A> editOrNewResponse() {
    return withNewResponseLike(java.util.Optional.ofNullable(buildResponse()).orElse(new HeadersHeaderOperationsBuilder().build()));
  }
  
  public ResponseNested<A> editOrNewResponseLike(HeadersHeaderOperations item) {
    return withNewResponseLike(java.util.Optional.ofNullable(buildResponse()).orElse(item));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HeadersFluent that = (HeadersFluent) o;
    if (!java.util.Objects.equals(request, that.request)) return false;
  
    if (!java.util.Objects.equals(response, that.response)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(request,  response,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (request != null) { sb.append("request:"); sb.append(request + ","); }
    if (response != null) { sb.append("response:"); sb.append(response); }
    sb.append("}");
    return sb.toString();
  }
  public class RequestNested<N> extends HeadersHeaderOperationsFluent<RequestNested<N>> implements Nested<N>{
    RequestNested(HeadersHeaderOperations item) {
      this.builder = new HeadersHeaderOperationsBuilder(this, item);
    }
    HeadersHeaderOperationsBuilder builder;
    
    public N and() {
      return (N) HeadersFluent.this.withRequest(builder.build());
    }
    
    public N endRequest() {
      return and();
    }
    
  
  }
  public class ResponseNested<N> extends HeadersHeaderOperationsFluent<ResponseNested<N>> implements Nested<N>{
    ResponseNested(HeadersHeaderOperations item) {
      this.builder = new HeadersHeaderOperationsBuilder(this, item);
    }
    HeadersHeaderOperationsBuilder builder;
    
    public N and() {
      return (N) HeadersFluent.this.withResponse(builder.build());
    }
    
    public N endResponse() {
      return and();
    }
    
  
  }

}
